==> pgmarket-1.3.2.tar.gz: pgmarket-1.3.2/DOCS/layersmenu-example/layersmenu-header.php <==
<? $treefile = "layersmenu.txt"; ?>

<script language="JavaScript">
<!--
NS4 = (document.layers) ? 1 : 0;
IE4 = (document.all) ? 1 : 0;
DOM = (document.getElementById) ? 1 : 0;
var gotlayers = 0;
var lastbutton='top';
// -->
</script>

<script language="JavaScript1.2">
<!--

function popUp(menuName,on) {
	if (gotlayers) {
		if (on) {
			moveLayers();
			if (NS4) {
				document.layers[menuName].visibility = "show";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "visible";
                        } else {
				document.all[menuName].style.visibility = "visible";
			}
		} else {
			if (NS4) {
				document.layers[menuName].visibility = "hide";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "hidden";
			} else {
				document.all[menuName].style.visibility = "hidden";
			}
		}
	}
}

<?

/* **************************************************************** */
/* Taken from PgMarket (GNU GPL) - Marco Pratesi - pratesi@telug.it */
/* **************************************************************** */

function string_cleanup_js ($string) {
// "cleans up" a string containing "strange" characters

	$string = str_replace(" ", "space", $string);
	$string = str_replace("-", "minus", $string);
	$string = str_replace("!", "exclam", $string);
	$string = str_replace("", "sterling", $string);
	$string = str_replace("$", "dollar", $string);
	$string = str_replace("%", "percent", $string);
	$string = str_replace("&", "ampersand", $string);
	$string = str_replace("/", "slash", $string);
	$string = str_replace("\\", "backslash", $string);
	$string = str_replace("(", "parenleft", $string);
	$string = str_replace(")", "parenright", $string);
	$string = str_replace("[", "bracketleft", $string);
	$string = str_replace("]", "bracketright", $string);
	$string = str_replace("{", "braceleft", $string);
	$string = str_replace("}", "braceright", $string);
	$string = str_replace("?", "question", $string);
	$string = str_replace("*", "asterisk", $string);
	$string = str_replace("@", "at", $string);
	$string = str_replace("", "paragraph", $string);
	$string = str_replace(">", "greater", $string);
	$string = str_replace("<", "lower", $string);
	$string = str_replace("", "degree", $string);
	$string = str_replace("#", "numbersign", $string);
	$string = str_replace("~", "tilde", $string);
	$string = str_replace("`", "grave", $string);
	$string = str_replace("'", "apostrophe", $string);
	$string = str_replace("", "cedilla", $string);

	return $string;

}

/* **************************************************************** */

$moveLayersNS4 = "";
$moveLayersDOM = "";
$moveLayersDef = "";
$shutdown = "";
$firstleveltable = "";

/* ******************************************************************** */
/* Taken from TreeMenu 1.0 (c) 1999 by Bjorge Dijkstra - bjorge@gmx.net */
/* ******************************************************************** */

$maxlevel=0;
$cnt=0;

$fd = fopen($treefile, "r");
if ($fd==0) die("Unable to open file ".$treefile);
while ($buffer = fgets($fd, 4096)) {
	$tree[$cnt][0]=strspn($buffer,".");
	$tmp=rtrim(substr($buffer,$tree[$cnt][0]));
	$node=explode("|",$tmp);
	$tree[$cnt][1]=$node[0];
	$stripped_tree[$cnt] = string_cleanup_js($tree[$cnt][1]) . $cnt;
	$tree[$cnt][2]=$node[1];
	$tree[$cnt][3]=$node[2];
	$tree[$cnt][4]=0;
	if ($tree[$cnt][0] > $maxlevel) $maxlevel=$tree[$cnt][0];
	$cnt++;
}

/* ******************************************************************** */

$abscissa_step = 140;
$abscissa_stepx5 = $abscissa_step*5;
for ($i=0; $i<$maxlevel; $i++)
	$abscissa[$i] = $i * $abscissa_step;
$ordinata_step = 15;
$ordinata[2] = 15-$ordinata_step;

for ($cnt=1; $cnt<count($tree); $cnt++) {
	$layername[$tree[$cnt][0]] = $stripped_tree[$cnt];

	for ($i=$tree[$cnt][0]+1; $i<$maxlevel; $i++)
		$ordinata[$i] = $ordinata[$i-1] + 1.5*$ordinata_step;
	$ordinata[$tree[$cnt][0]] += $ordinata_step;

	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {
		echo "function popUp" . $stripped_tree[$cnt] . "() {\n" . "shutdown();\n";
		for ($i=2; $i<=$tree[$cnt][0]; $i++)
			echo "popUp('" . $layername[$i] . "',true);\n";
		echo "}\n";

		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.width = " . $abscissa_step . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";

		$shutdown .= "popUp('" . $stripped_tree[$cnt] . "',false);\n"; 
	}

	if ($tree[$cnt][0] > 2) {
		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree))
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\"";
		$layer[$layername[$tree[$cnt][0]-1]] .= ">" . $tree[$cnt][1] . "</a><br>\n";
/*
		if (!($tree[$cnt+1][0]<=$tree[$cnt][0]))
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"#\" onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
		else
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
*/
	}

	if ($tree[$cnt][0] == 2)
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree))
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
//			$firstleveltable .= "<a href=\"#\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
		else
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\">" . $tree[$cnt][1] . "</a><br>\n";

}

$shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocument.onmousedown = function() { shutdown(); }\n} else {\ndocument.onclick = function() { shutdown(); } \n}\n";

?>

function moveLayers() {
if (gotlayers) {
if (NS4) {
<?=$moveLayersNS4?>
} else if (DOM) {
<?=$moveLayersDOM?>
} else {
<?=$moveLayersDef?>
}}}
<?=$shutdown?>

// -->
</script>

==> pgmarket-1.3.3.tar.gz: pgmarket-1.3.3/DOCS/layersmenu-example/layersmenu-header.php <==
<? $treefile = "layersmenu.txt"; ?>

<script language="JavaScript">
<!--
NS4 = (document.layers) ? 1 : 0;
IE4 = (document.all) ? 1 : 0;
DOM = (document.getElementById) ? 1 : 0;
var gotlayers = 0;
var lastbutton='top';
// -->
</script>

<script language="JavaScript1.2">
<!--

function popUp(menuName,on) {
	if (gotlayers) {
		if (on) {
			moveLayers();
			if (NS4) {
				document.layers[menuName].visibility = "show";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "visible";
                        } else {
				document.all[menuName].style.visibility = "visible";
			}
		} else {
			if (NS4) {
				document.layers[menuName].visibility = "hide";
			} else if (DOM) {
				document.getElementById(menuName).style.visibility = "hidden";
			} else {
				document.all[menuName].style.visibility = "hidden";
			}
		}
	}
}

<?

/* **************************************************************** */
/* Taken from PgMarket (GNU GPL) - Marco Pratesi - pratesi@telug.it */
/* **************************************************************** */

function string_cleanup_js ($string) {
// "cleans up" a string containing "strange" characters

	$string = str_replace(" ", "space", $string);
	$string = str_replace("-", "minus", $string);
	$string = str_replace("!", "exclam", $string);
	$string = str_replace("", "sterling", $string);
	$string = str_replace("$", "dollar", $string);
	$string = str_replace("%", "percent", $string);
	$string = str_replace("&", "ampersand", $string);
	$string = str_replace("/", "slash", $string);
	$string = str_replace("\\", "backslash", $string);
	$string = str_replace("(", "parenleft", $string);
	$string = str_replace(")", "parenright", $string);
	$string = str_replace("[", "bracketleft", $string);
	$string = str_replace("]", "bracketright", $string);
	$string = str_replace("{", "braceleft", $string);
	$string = str_replace("}", "braceright", $string);
	$string = str_replace("?", "question", $string);
	$string = str_replace("*", "asterisk", $string);
	$string = str_replace("@", "at", $string);
	$string = str_replace("", "paragraph", $string);
	$string = str_replace(">", "greater", $string);
	$string = str_replace("<", "lower", $string);
	$string = str_replace("", "degree", $string);
	$string = str_replace("#", "numbersign", $string);
	$string = str_replace("~", "tilde", $string);
	$string = str_replace("`", "grave", $string);
	$string = str_replace("'", "apostrophe", $string);
	$string = str_replace("", "cedilla", $string);

	return $string;

}

/* **************************************************************** */

$moveLayersNS4 = "";
$moveLayersDOM = "";
$moveLayersDef = "";
$shutdown = "";
$firstleveltable = "";

/* ******************************************************************** */
/* Taken from TreeMenu 1.0 (c) 1999 by Bjorge Dijkstra - bjorge@gmx.net */
/* ******************************************************************** */

$maxlevel=0;
$cnt=0;

$fd = fopen($treefile, "r");
if ($fd==0) die("Unable to open file ".$treefile);
while ($buffer = fgets($fd, 4096)) {
	$tree[$cnt][0]=strspn($buffer,".");
	$tmp=rtrim(substr($buffer,$tree[$cnt][0]));
	$node=explode("|",$tmp);
	$tree[$cnt][1]=$node[0];
	$stripped_tree[$cnt] = string_cleanup_js($tree[$cnt][1]) . $cnt;
	$tree[$cnt][2]=$node[1];
	$tree[$cnt][3]=$node[2];
	$tree[$cnt][4]=0;
	if ($tree[$cnt][0] > $maxlevel) $maxlevel=$tree[$cnt][0];
	$cnt++;
}

/* ******************************************************************** */

$abscissa_step = 140;
$abscissa_stepx5 = $abscissa_step*5;
for ($i=0; $i<$maxlevel; $i++)
	$abscissa[$i] = $i * $abscissa_step;
$ordinata_step = 15;
$ordinata[2] = 15-$ordinata_step;

for ($cnt=1; $cnt<count($tree); $cnt++) {
	$layername[$tree[$cnt][0]] = $stripped_tree[$cnt];

	for ($i=$tree[$cnt][0]+1; $i<$maxlevel; $i++)
		$ordinata[$i] = $ordinata[$i-1] + 1.5*$ordinata_step;
	$ordinata[$tree[$cnt][0]] += $ordinata_step;

	if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree)) {
		echo "function popUp" . $stripped_tree[$cnt] . "() {\n" . "shutdown();\n";
		for ($i=2; $i<=$tree[$cnt][0]; $i++)
			echo "popUp('" . $layername[$i] . "',true);\n";
		echo "}\n";

		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersNS4 .= "document.layers['" . $stripped_tree[$cnt] . "'].top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.left = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.top = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDOM .= "document.getElementById('" . $stripped_tree[$cnt] . "').style.width = " . $abscissa_step . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelLeft = " . $abscissa[$tree[$cnt][0]-1] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelTop = " . $ordinata[$tree[$cnt][0]] . ";\n";
		$moveLayersDef .= "document.all['" . $stripped_tree[$cnt] . "'].style.pixelWidth = " . $abscissa_step . ";\n";

		$shutdown .= "popUp('" . $stripped_tree[$cnt] . "',false);\n"; 
	}

	if ($tree[$cnt][0] > 2) {
		$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\"";
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree))
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\"";
		else
			$layer[$layername[$tree[$cnt][0]-1]] .= " onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\"";
		$layer[$layername[$tree[$cnt][0]-1]] .= ">" . $tree[$cnt][1] . "</a><br>\n";
/*
		if ($tree[$cnt+1][0]>$tree[$cnt][0])
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"#\" onMouseover=\"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
		else
			$layer[$layername[$tree[$cnt][0]-1]] .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover=\"popUp" . $layername[$tree[$cnt][0]-1] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
*/
	}

	if ($tree[$cnt][0] == 2)
		if ($tree[$cnt+1][0]>$tree[$cnt][0] && $cnt+1<count($tree))
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
//			$firstleveltable .= "<a href=\"#\" onMouseover = \"popUp" . $stripped_tree[$cnt] . "();\">" . $tree[$cnt][1] . "</a><br>\n";
		else
			$firstleveltable .= "<a href=\"" . $tree[$cnt][2] . "\">" . $tree[$cnt][1] . "</a><br>\n";

}

$shutdown = "function shutdown() {\n" . $shutdown . "}\n" . "if (NS4) {\ndocument.onmousedown = function() { shutdown(); }\n} else {\ndocument.onclick = function() { shutdown(); } \n}\n";

?>

function moveLayers() {
if (gotlayers) {
if (NS4) {
<?=$moveLayersNS4?>
} else if (DOM) {
<?=$moveLayersDOM?>
} else {
<?=$moveLayersDef?>
}}}
<?=$shutdown?>

// -->
</script>
